% Estabelecimento de uma nova ligao via RS-232
%
% [handler,state]=initcom(gate,rate)
%
% Entradas:
%  gate    -> Porta a utilizar (1,2,...)
%  rate    -> baudrate a definir
% Sadas:
%  handler -> ID da linha de comunicaes
%  state   -> Configuraes da linha
%
% (c) Milton Ruas da Silva, 2006

function [handler,state]=initcom(gate,rate)

% Verificao dos argumentos de sada
if (nargout==0)
    error('myfunction:initComm:outargs',' necessrio definir pelo menos uma variavel de sada!');
end

% Argumentos default:
if (nargin<2)
    rate=115200;     % BaudRate=19200
end
if (nargin==0)
    gate=1;         % gate=COM1
end

% Abertura da porta de comunicao
handler=cportopen(['com' num2str(gate)]);
if (handler==0)
    error('cport:cportopen:GateNotOpened',['Failed to open gate COM',num2str(gate)]);
end

% Configurao do ritmo de transmisso
state=cportconfig(handler,'BaudRate',rate, ...
                          'ByteSize',8, ...
                          'fNull','OFF', ...
                          'fDtrControl','OFF', ...
                          'fRtsControl','OFF', ...
                          'fAbortOnError','ON', ...
                          'ErrorChar',-1, ...
                          'ReadIntervalTimeout',1, ...
                          'ReadTotalTimeoutMultiplier',5, ...
                          'ReadTotalTimeoutConstant',100, ...
                          'WriteTotalTimeoutMultiplier',1000, ...
                          'WriteTotalTimeoutConstant',1000);
                          

% Reset das comunicaes
[stat,ErrStr]=cportreset(handler);

% Verificao da ocorrencia de erros no RESET
if (stat==0)
    error('cport:cportreset:ResetFailed','Cannot reset communications!');
    
    % Encerramento da porta
    stat=cportclose(handler);
    % Verificao da ocorrncia de erros no encerramento
    if (stat==0)
        error('cport:cportclose:CloseFailed','Cannot close communications gate!');
    end
end

% Apresentao de erros ocorridos antes do RESET
if (length(ErrStr)>0)
    fprintf('Previous errors:\n%s\n',ErrStr);
end
