% Leitura de um parametro sensorial dos servos de um SCU
%
% [servos,state,rx,error,errorstr,tries]=readjoint(H,scu_id,param)
%
% Entradas:
% H        => Handler para comunicar com o Master
% scu_id   => Identificador do SCU alvo
% param    => Parametro a ler
%
% Sadas:
% servos   => Parametro de sada
% state    => Bits de estado dos servos
% rx       => Mensagem de baixo nvel recebida
% error    => Cdigo de erro, se existente
% errorstr => String descritiva do erro
% tries    => Nmero de tentativas para efectuar a comunicao
%
% (c) Milton Ruas da Silva, 2006

function [servos,state,rx,error,errorstr]=readjoint(H,scu_id,param)

% Carregamento em memria das constantes
data;

% Construo da mensagem a enviar
message=buildmessage(OP_READ_SENSORS,scu_id,param);

% Envio da mensagem de request e leitura da resposta
[rx,error,errorstr]=sendmessage(H,message);

% O array servos indica o parametro pedido para cada um dos servos
servos=[];
state=[];

if (~error)
    % Estado do sistema
    for i=7:-1:0
         state=[state bitand(bitshift(rx(end),-i),1)];
    end

    servos=intsigned(double(rx(3:end-1)),8);
    % Converso para inteiro sem sinal, caso seja corrente o parametro
    if (param==PARAM_CURRENT), servos = intunsigned(servos,8); end
    errorstr='';
end